@@ -322,6 +322,8 @@ int
 main (int   argc,
       char *argv[])
 {
+  const gchar *s;
+  gchar **sv;
   GList *list, *t;
   GSList *slist, *st;
   GHashTable *hash_table;
@@ -434,8 +436,23 @@ main (int   argc,
   g_free (string);
   g_print ("user: %s\n", g_get_user_name ());
   g_print ("real: %s\n", g_get_real_name ());
-  g_print ("home: %s\n", g_get_home_dir ());
+  s = g_get_home_dir ();
+  g_print ("home: %s\n", s ? s : "NULL!");
+  s = g_get_home_dir ();
+  g_print ("home: %s\n", s ? s : "NULL!");
+  s = g_get_user_data_dir ();
+  g_print ("user_data: %s\n", s ? s : "NULL!");
+  s = g_get_user_config_dir ();
+  g_print ("user_config: %s\n", s ? s : "NULL!");
+  s = g_get_user_cache_dir ();
+  g_print ("user_cache: %s\n", s ? s : "NULL!");
+  sv = (gchar **) g_get_system_data_dirs ();
+  g_print ("system_data: %s\n", sv ? g_strjoinv (G_SEARCHPATH_SEPARATOR_S, sv) : "NULL!");
+  sv = (gchar **) g_get_system_config_dirs ();
+  g_print ("system_config: %s\n", s ? g_strjoinv (G_SEARCHPATH_SEPARATOR_S, sv) : "NULL!");
   g_print ("tmp-dir: %s\n", g_get_tmp_dir ());
+  sv = (gchar **) g_get_language_names ();
+  g_print ("languages: %s\n", s ? g_strjoinv (":", sv) : "NULL!");
 
   /* type sizes */
   g_print ("checking size of gint8: %"    G_GSIZE_FORMAT, sizeof (gint8));
@@ -1230,6 +1247,8 @@ main (int   argc,
   g_message ("the next warning is a test:");
   string = NULL;
   g_print (string);
+  g_message ("non-printable UTF-8: \"\xc3\xa4\xda\x85\"");
+  g_message ("unsafe chars: \"\x10\x11\x12\n\t\x7f\x81\x82\x83\"");
 
   g_print ("checking endian macros (host is ");
 #if G_BYTE_ORDER == G_BIG_ENDIAN
@@ -1243,7 +1262,7 @@ main (int   argc,
 
   g_print ("ok\n");
 
-  if (g_get_charset (&charset))
+  if (g_get_charset ((G_CONST_RETURN char**)&charset))
     g_print ("current charset is UTF-8: %s\n", charset);
   else
     g_print ("current charset is not UTF-8: %s\n", charset);
